@@ -2,6 +2,24 @@
 更新内容一览
 """
 
+"""
+2022/5/30
+control_version:0.6.3
+blcoklyFile_version:2.2.6
+blockly_version:2.2.2
+基本稳定了本地化语音
+
+"""
+
+"""
+2022/5/29
+control_version:0.6.2
+blcoklyFile_version:2.2.6
+blockly_version:2.2.2
+修改路径bug
+
+"""
+
 """
 2022/5/23
 control_version:0.6.1
